@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtcore_python.h>
 #include <pyside2_qtgui_python.h>
@@ -63,44 +57,49 @@
 // Binded library includes
 #include <qquickwidget.h>
 // Conversion Includes - Primitive Types
-#include "pysideqmlregistertype.h"
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include "pysideqmlregistertype.h"
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QQUICKWIDGET_IDX                                         0
-#define SBK_QQUICKWIDGET_RESIZEMODE_IDX                              1
-#define SBK_QQUICKWIDGET_STATUS_IDX                                  2
-#define SBK_QtQuickWidgets_IDX_COUNT                                 3
-
+enum : int {
+    SBK_QQUICKWIDGET_IDX                                     = 0,
+    SBK_QQUICKWIDGET_RESIZEMODE_IDX                          = 1,
+    SBK_QQUICKWIDGET_STATUS_IDX                              = 2,
+    SBK_QtQuickWidgets_IDX_COUNT                             = 3
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtQuickWidgetsTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtQuickWidgetsModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtQuickWidgetsTypeConverters;
 
 // Converter indices
-#define SBK_QTQUICKWIDGETS_QLIST_QACTIONPTR_IDX                      0 // QList<QAction* >
-#define SBK_QTQUICKWIDGETS_QLIST_QQMLERROR_IDX                       1 // QList<QQmlError >
-#define SBK_QTQUICKWIDGETS_QLIST_QVARIANT_IDX                        2 // QList<QVariant >
-#define SBK_QTQUICKWIDGETS_QLIST_QSTRING_IDX                         3 // QList<QString >
-#define SBK_QTQUICKWIDGETS_QMAP_QSTRING_QVARIANT_IDX                 4 // QMap<QString,QVariant >
-#define SBK_QtQuickWidgets_CONVERTERS_IDX_COUNT                      5
-
+enum : int {
+    SBK_QTQUICKWIDGETS_QLIST_QACTIONPTR_IDX                  = 0, // QList<QAction* >
+    SBK_QTQUICKWIDGETS_QLIST_QQMLERROR_IDX                   = 1, // QList<QQmlError >
+    SBK_QTQUICKWIDGETS_QLIST_QVARIANT_IDX                    = 2, // QList<QVariant >
+    SBK_QTQUICKWIDGETS_QLIST_QSTRING_IDX                     = 3, // QList<QString >
+    SBK_QTQUICKWIDGETS_QMAP_QSTRING_QVARIANT_IDX             = 4, // QMap<QString,QVariant >
+    SBK_QtQuickWidgets_CONVERTERS_IDX_COUNT                  = 5
+};
 // Macros for type check
 
 namespace Shiboken
