@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtcore_python.h>
 
@@ -60,39 +54,44 @@
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
-#include <signalmanager.h>
 #include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QStack>
+#include <pysideqflags.h>
+#include <QLinkedList>
 #include <QList>
 #include <QMap>
-#include <pysideqflags.h>
+#include <QMultiMap>
 #include <QPair>
 #include <QQueue>
-#include <QMultiMap>
 #include <QSet>
-#include <QLinkedList>
+#include <QStack>
 #include <QVector>
 
 // Type indices
-#define SBK_QX11INFO_IDX                                             1
-#define SBK_QX11INFO_PEEKOPTION_IDX                                  2
-#define SBK_QFLAGS_QX11INFO_PEEKOPTION__IDX                          0
-#define SBK_QtX11Extras_IDX_COUNT                                    3
-
+enum : int {
+    SBK_QX11INFO_IDX                                         = 1,
+    SBK_QX11INFO_PEEKOPTION_IDX                              = 2,
+    SBK_QFLAGS_QX11INFO_PEEKOPTION_IDX                       = 0,
+    SBK_QtX11Extras_IDX_COUNT                                = 3
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtX11ExtrasTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtX11ExtrasModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtX11ExtrasTypeConverters;
 
 // Converter indices
-#define SBK_QTX11EXTRAS_QLIST_QVARIANT_IDX                           0 // QList<QVariant >
-#define SBK_QTX11EXTRAS_QLIST_QSTRING_IDX                            1 // QList<QString >
-#define SBK_QTX11EXTRAS_QMAP_QSTRING_QVARIANT_IDX                    2 // QMap<QString,QVariant >
-#define SBK_QtX11Extras_CONVERTERS_IDX_COUNT                         3
-
+enum : int {
+    SBK_QTX11EXTRAS_QLIST_QVARIANT_IDX                       = 0, // QList<QVariant >
+    SBK_QTX11EXTRAS_QLIST_QSTRING_IDX                        = 1, // QList<QString >
+    SBK_QTX11EXTRAS_QMAP_QSTRING_QVARIANT_IDX                = 2, // QMap<QString,QVariant >
+    SBK_QtX11Extras_CONVERTERS_IDX_COUNT                     = 3
+};
 // Macros for type check
 
 namespace Shiboken
@@ -100,7 +99,7 @@ namespace Shiboken
 
 // PyType functions, to get the PyObjectType for a type T
 template<> inline PyTypeObject* SbkType< ::QX11Info::PeekOption >() { return SbkPySide2_QtX11ExtrasTypes[SBK_QX11INFO_PEEKOPTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QFlags<QX11Info::PeekOption> >() { return SbkPySide2_QtX11ExtrasTypes[SBK_QFLAGS_QX11INFO_PEEKOPTION__IDX]; }
+template<> inline PyTypeObject* SbkType< ::QFlags<QX11Info::PeekOption> >() { return SbkPySide2_QtX11ExtrasTypes[SBK_QFLAGS_QX11INFO_PEEKOPTION_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QX11Info >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtX11ExtrasTypes[SBK_QX11INFO_IDX]); }
 
 } // namespace Shiboken
