@@ -46,112 +46,111 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qxmlserializer.h>
 #include <qxmlschema.h>
+#include <qxmlserializer.h>
 #include <qxmlresultitems.h>
 #include <qxmlformatter.h>
 #include <qabstracturiresolver.h>
 #include <qxmlnamepool.h>
 #include <qabstractxmlnodemodel.h>
 #include <qsourcelocation.h>
+#include <qabstractmessagehandler.h>
 #include <qabstractxmlreceiver.h>
 #include <qxmlname.h>
-#include <qabstractmessagehandler.h>
 #include <qxmlschemavalidator.h>
 #include <qxmlquery.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
-#include <signalmanager.h>
 #include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QStack>
+#include <pysideqflags.h>
+#include <QLinkedList>
 #include <QList>
 #include <QMap>
-#include <pysideqflags.h>
+#include <QMultiMap>
 #include <QPair>
 #include <QQueue>
-#include <QMultiMap>
 #include <QSet>
-#include <QLinkedList>
+#include <QStack>
 #include <QVector>
 
 // Type indices
-#define SBK_QXMLRESULTITEMS_IDX                                      16
-#define SBK_QXMLNAMEPOOL_IDX                                         10
-#define SBK_QABSTRACTXMLRECEIVER_IDX                                 5
-#define SBK_QXMLSERIALIZER_IDX                                       19
-#define SBK_QXMLFORMATTER_IDX                                        7
-#define SBK_QXMLITEM_IDX                                             8
-#define SBK_QABSTRACTXMLNODEMODEL_IDX                                2
-#define SBK_QABSTRACTXMLNODEMODEL_SIMPLEAXIS_IDX                     4
-#define SBK_QABSTRACTXMLNODEMODEL_NODECOPYSETTING_IDX                3
-#define SBK_QXMLNODEMODELINDEX_IDX                                   11
-#define SBK_QXMLNODEMODELINDEX_NODEKIND_IDX                          13
-#define SBK_QXMLNODEMODELINDEX_DOCUMENTORDER_IDX                     12
-#define SBK_QXMLNAME_IDX                                             9
-#define SBK_QSOURCELOCATION_IDX                                      6
-#define SBK_QABSTRACTURIRESOLVER_IDX                                 1
-#define SBK_QABSTRACTMESSAGEHANDLER_IDX                              0
-#define SBK_QXMLSCHEMAVALIDATOR_IDX                                  18
-#define SBK_QXMLSCHEMA_IDX                                           17
-#define SBK_QXMLQUERY_IDX                                            14
-#define SBK_QXMLQUERY_QUERYLANGUAGE_IDX                              15
-#define SBK_QtXmlPatterns_IDX_COUNT                                  20
-
+enum : int {
+    SBK_QABSTRACTMESSAGEHANDLER_IDX                          = 0,
+    SBK_QABSTRACTURIRESOLVER_IDX                             = 1,
+    SBK_QABSTRACTXMLNODEMODEL_IDX                            = 2,
+    SBK_QABSTRACTXMLNODEMODEL_SIMPLEAXIS_IDX                 = 4,
+    SBK_QABSTRACTXMLNODEMODEL_NODECOPYSETTING_IDX            = 3,
+    SBK_QABSTRACTXMLRECEIVER_IDX                             = 5,
+    SBK_QSOURCELOCATION_IDX                                  = 6,
+    SBK_QXMLFORMATTER_IDX                                    = 7,
+    SBK_QXMLITEM_IDX                                         = 8,
+    SBK_QXMLNAME_IDX                                         = 9,
+    SBK_QXMLNAMEPOOL_IDX                                     = 10,
+    SBK_QXMLNODEMODELINDEX_IDX                               = 11,
+    SBK_QXMLNODEMODELINDEX_NODEKIND_IDX                      = 13,
+    SBK_QXMLNODEMODELINDEX_DOCUMENTORDER_IDX                 = 12,
+    SBK_QXMLQUERY_IDX                                        = 14,
+    SBK_QXMLQUERY_QUERYLANGUAGE_IDX                          = 15,
+    SBK_QXMLRESULTITEMS_IDX                                  = 16,
+    SBK_QXMLSCHEMA_IDX                                       = 17,
+    SBK_QXMLSCHEMAVALIDATOR_IDX                              = 18,
+    SBK_QXMLSERIALIZER_IDX                                   = 19,
+    SBK_QtXmlPatterns_IDX_COUNT                              = 20
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtXmlPatternsTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtXmlPatternsModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtXmlPatternsTypeConverters;
 
 // Converter indices
-#define SBK_QTXMLPATTERNS_QVECTOR_QXMLNODEMODELINDEX_IDX             0 // QVector<QXmlNodeModelIndex >
-#define SBK_QTXMLPATTERNS_QVECTOR_QXMLNAME_IDX                       1 // QVector<QXmlName >
-#define SBK_QTXMLPATTERNS_QLIST_QOBJECTPTR_IDX                       2 // const QList<QObject* > &
-#define SBK_QTXMLPATTERNS_QLIST_QBYTEARRAY_IDX                       3 // QList<QByteArray >
-#define SBK_QTXMLPATTERNS_QLIST_QVARIANT_IDX                         4 // QList<QVariant >
-#define SBK_QTXMLPATTERNS_QLIST_QSTRING_IDX                          5 // QList<QString >
-#define SBK_QTXMLPATTERNS_QMAP_QSTRING_QVARIANT_IDX                  6 // QMap<QString,QVariant >
-#define SBK_QtXmlPatterns_CONVERTERS_IDX_COUNT                       7
-
+enum : int {
+    SBK_QTXMLPATTERNS_QLIST_QOBJECTPTR_IDX                   = 0, // const QList<QObject* > &
+    SBK_QTXMLPATTERNS_QLIST_QBYTEARRAY_IDX                   = 1, // QList<QByteArray >
+    SBK_QTXMLPATTERNS_QVECTOR_QXMLNODEMODELINDEX_IDX         = 2, // QVector<QXmlNodeModelIndex >
+    SBK_QTXMLPATTERNS_QVECTOR_QXMLNAME_IDX                   = 3, // QVector<QXmlName >
+    SBK_QTXMLPATTERNS_QLIST_QVARIANT_IDX                     = 4, // QList<QVariant >
+    SBK_QTXMLPATTERNS_QLIST_QSTRING_IDX                      = 5, // QList<QString >
+    SBK_QTXMLPATTERNS_QMAP_QSTRING_QVARIANT_IDX              = 6, // QMap<QString,QVariant >
+    SBK_QtXmlPatterns_CONVERTERS_IDX_COUNT                   = 7
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QXmlResultItems >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLRESULTITEMS_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QXmlNamePool >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLNAMEPOOL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QAbstractXmlReceiver >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QABSTRACTXMLRECEIVER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QXmlSerializer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLSERIALIZER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QXmlFormatter >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLFORMATTER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QXmlItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLITEM_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QAbstractMessageHandler >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QABSTRACTMESSAGEHANDLER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QAbstractUriResolver >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QABSTRACTURIRESOLVER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QAbstractXmlNodeModel::SimpleAxis >() { return SbkPySide2_QtXmlPatternsTypes[SBK_QABSTRACTXMLNODEMODEL_SIMPLEAXIS_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QAbstractXmlNodeModel::NodeCopySetting >() { return SbkPySide2_QtXmlPatternsTypes[SBK_QABSTRACTXMLNODEMODEL_NODECOPYSETTING_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QAbstractXmlNodeModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QABSTRACTXMLNODEMODEL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QAbstractXmlReceiver >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QABSTRACTXMLRECEIVER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QSourceLocation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QSOURCELOCATION_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QXmlFormatter >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLFORMATTER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QXmlItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLITEM_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QXmlName >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLNAME_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QXmlNamePool >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLNAMEPOOL_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QXmlNodeModelIndex::NodeKind >() { return SbkPySide2_QtXmlPatternsTypes[SBK_QXMLNODEMODELINDEX_NODEKIND_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QXmlNodeModelIndex::DocumentOrder >() { return SbkPySide2_QtXmlPatternsTypes[SBK_QXMLNODEMODELINDEX_DOCUMENTORDER_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QXmlNodeModelIndex >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLNODEMODELINDEX_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QXmlName >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLNAME_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QSourceLocation >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QSOURCELOCATION_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QAbstractUriResolver >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QABSTRACTURIRESOLVER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QAbstractMessageHandler >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QABSTRACTMESSAGEHANDLER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QXmlSchemaValidator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLSCHEMAVALIDATOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QXmlSchema >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLSCHEMA_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QXmlQuery::QueryLanguage >() { return SbkPySide2_QtXmlPatternsTypes[SBK_QXMLQUERY_QUERYLANGUAGE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QXmlQuery >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLQUERY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QXmlResultItems >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLRESULTITEMS_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QXmlSchema >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLSCHEMA_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QXmlSchemaValidator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLSCHEMAVALIDATOR_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QXmlSerializer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtXmlPatternsTypes[SBK_QXMLSERIALIZER_IDX]); }
 
 } // namespace Shiboken
 
